@@ -321,6 +321,7 @@ gdu_edit_linux_md_dialog_constructed (GObject *object)
         GduEditLinuxMdDialog *dialog = GDU_EDIT_LINUX_MD_DIALOG (object);
         GduLinuxMdDrive *linux_md_drive;
         GtkWidget *content_area;
+        GtkWidget *action_area;
         GtkWidget *vbox;
         GtkWidget *vbox2;
         GtkWidget *hbox;
@@ -358,11 +359,11 @@ gdu_edit_linux_md_dialog_constructed (GObject *object)
         vbox = gtk_vbox_new (FALSE, 6);
         gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+        action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 0);
-        gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 5);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->action_area), 6);
+        gtk_box_set_spacing (GTK_BOX (content_area), 0);
+        gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
+        gtk_box_set_spacing (GTK_BOX (action_area), 6);
 
         name = gdu_presentable_get_name (GDU_PRESENTABLE (linux_md_drive));
         vpd_name = gdu_presentable_get_vpd_name (GDU_PRESENTABLE (linux_md_drive));
